Imports System
Imports System.Drawing
Imports System.Collections.Generic
Imports System.Text
Imports System.Windows.Forms
Imports System.Runtime.InteropServices

Namespace ADX_IE_NetControl_VB
    Class MyCustomToolStrip
        Inherits ToolStrip
        Friend hThemeModule As IntPtr = IntPtr.Zero
        Friend IsThemeActive As DllIsThemeActive = Nothing
        Friend DrawThemeParentBackground As DllDrawThemeParentBackground = _
          Nothing

        Friend Delegate Function DllIsThemeActive() As Boolean
        Friend Delegate Sub DllDrawThemeParentBackground(ByVal hWnd As _
          IntPtr, ByVal hDC As IntPtr, ByRef rect As RECT)

        <ComVisible(False), StructLayout(LayoutKind.Sequential, Pack:=4)> _
        Public Structure RECT
            Public Left As Integer
            Public Top As Integer
            Public Right As Integer
            Public Bottom As Integer

            Public Sub New(ByVal left__1 As Integer, ByVal top__2 As _
              Integer, ByVal right__3 As Integer, ByVal bottom__4 As Integer)
                Left = left__1
                Top = top__2
                Right = right__3
                Bottom = bottom__4
            End Sub

            Public Sub New(ByVal rect As Rectangle)
                Left = rect.Left
                Top = rect.Top
                Right = rect.Right
                Bottom = rect.Bottom
            End Sub

            Public Function ToRectangle() As Rectangle
                Return New Rectangle(Left, Top, Right, Bottom - 1)
            End Function
        End Structure

        <DllImport("kernel32.dll")> _
        Public Shared Function FreeLibrary(ByVal hModule As IntPtr) As Boolean
        End Function

        <DllImport("kernel32.dll")> _
        Public Shared Function LoadLibrary(ByVal lpFileName As String) As _
          IntPtr
        End Function

        <DllImport("kernel32.dll", CharSet:=CharSet.Ansi)> _
        Public Shared Function GetProcAddress(ByVal hModule As IntPtr, ByVal _
          lpProcName As String) As IntPtr
        End Function

        Public Sub New()
            MyBase.New()
            If Not Me.DesignMode Then
                Me.DoubleBuffered = True

                hThemeModule = LoadLibrary("UxTheme.dll")
                If hThemeModule <> IntPtr.Zero Then
                    Dim dllIsThemeActive As IntPtr = GetProcAddress _
                      (hThemeModule, "IsThemeActive")
                    If dllIsThemeActive <> IntPtr.Zero Then
                        IsThemeActive = DirectCast _
                          (Marshal.GetDelegateForFunctionPointer _
                          (dllIsThemeActive, GetType(DllIsThemeActive)), _
                          DllIsThemeActive)
                    End If

                    Dim dllDrawThemeParentBackground As IntPtr = _
                      GetProcAddress(hThemeModule, "DrawThemeParentBackground")
                    If dllDrawThemeParentBackground <> IntPtr.Zero Then
                        DrawThemeParentBackground = DirectCast _
                          (Marshal.GetDelegateForFunctionPointer _
                          (dllDrawThemeParentBackground, _
                          GetType(DllDrawThemeParentBackground)), _
                          DllDrawThemeParentBackground)
                    End If

                    Application.EnableVisualStyles()
                    Application.DoEvents()
                End If
            End If
        End Sub

        Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
            If disposing Then
                If hThemeModule <> IntPtr.Zero Then
                    FreeLibrary(hThemeModule)
                    hThemeModule = IntPtr.Zero
                End If
            End If
            MyBase.Dispose(disposing)
        End Sub

        Protected Overloads Overrides Sub OnPaintBackground(ByVal e As _
          PaintEventArgs)
            If hThemeModule <> IntPtr.Zero AndAlso Not DesignMode Then
                If IsThemeActive() Then
                    Dim hdc As IntPtr = IntPtr.Zero
                    Dim rect As New RECT(0, 0, Width, Height)

                    hdc = e.Graphics.GetHdc()
                    If hdc <> IntPtr.Zero Then
                        Try
                            DrawThemeParentBackground(Me.Handle, hdc, rect)
                        Finally
                            e.Graphics.ReleaseHdc(hdc)
                        End Try
                    End If
                    Exit Sub
                End If
            End If
            MyBase.OnPaintBackground(e)
        End Sub

        Protected Overloads Overrides Sub OnPaint(ByVal e As PaintEventArgs)
            MyBase.OnPaint(e)
            If hThemeModule <> IntPtr.Zero AndAlso Not DesignMode Then
                If IsThemeActive() Then
                    Dim hdc As IntPtr = IntPtr.Zero
                    Dim rect As New RECT(0, Height - 2, Width, Height)

                    hdc = e.Graphics.GetHdc()
                    If hdc <> IntPtr.Zero Then
                        Try
                            DrawThemeParentBackground(Me.Handle, hdc, rect)
                        Finally
                            e.Graphics.ReleaseHdc(hdc)
                        End Try
                    End If
                End If
            End If
        End Sub
    End Class
End Namespace